@@ -4,25 +4,23 @@ from .utils.parser import *
 
 BASE_URL = Api()
 
+
 class Hentaifox(object):
-    """ HentaiFox API wrapper 
-    
+    """HentaiFox API wrapper
+
     Methods
     -------
     get : function
         Get doujin API from Id
 
-    search_by_latest : function
-        Search for doujin based on the latest
-
-    search_by_popular : function
-        Search for doujin based on the popular
+    search : function
+        Search for doujin wirh query and page number given
 
     get_random : function
-        Gets random doujin on hentaifox
+        Get random doujin
     """
 
-    def __init__(self, api_key: str = ''):
+    def __init__(self, api_key: str = ""):
         """Initializes the Hentaifox.
 
         Parameters
@@ -30,11 +28,11 @@ class Hentaifox(object):
         api_key : str
             scathach.dev API key (optional)
         """
-        if api_key == '':
+        if api_key == "":
             self.api_key = None
         else:
             self.api_key = api_key
-        self.specs = {'api_key': self.api_key}
+        self.specs = {"api_key": self.api_key}
 
     async def get(self, book: int):
         """Get doujin API from Id
@@ -57,24 +55,22 @@ class Hentaifox(object):
             The book object that represents the specific id response.
         """
 
-        self.specs['g'] = book
+        self.specs["book"] = book
 
         try:
             book = int(book)
         except ValueError:
-            raise ValueError('Book must be an int')
+            raise ValueError("Book must be an int")
 
-        data = requests.get(BASE_URL.hentaifox, params=self.specs)
-        if data.json()['type'] is None:
-            raise ValueError('No results found')
+        data = requests.get(BASE_URL.hentaifox + "/get", params=self.specs)
 
-        self.final = json.loads(better_object(data.json()))
+        if data.status_code != 200:
+            raise ValueError("No results found")
 
-        return better_object(self.final)
+        return better_object(data.json())
 
-
-    async def search_by_latest(self, query: str, page: int = 1):
-        """Search for doujin based on the latest 
+    async def search(self, query: str, page: int = 1, sort: str = "latest"):
+        """Search for doujin based on the latest
 
         path: https://hentaifox.com/search/?q=alter&sort=latest
 
@@ -82,49 +78,12 @@ class Hentaifox(object):
         ----------
         query : str
             The query to search for
-        
+
         page : int
             The page number to search
 
-        Raises
-        ------
-        ValueError
-            If the doujin is not found.
-
-        Returns
-        -------
-        dict
-            The list object that represents the doujin response.
-        """
-
-        self.specs['query'] = query
-        self.specs['sort'] = "latest"
-        self.specs['page'] = page
-
-        query = auto_space(query)
-
-        if query == '':
-            raise ValueError('Query must be given')
-        data = requests.get(BASE_URL.hentaifox + 'args.php', params=self.specs)
-
-        if len(data.json()) == 0:
-            raise ValueError('No results found')
-
-        return better_object(data.json())
-
-
-    async def search_by_popular(self, query: str, page: int = 1):
-        """Search for doujin based on the latest 
-
-        path: https://hentaifox.com/search/?q=alter&sort=popular
-
-        Parameters
-        ----------
-        query : str
-            The query to search for
-        
-        page : int
-            The page number to search, Default is 1
+        sort : str
+            The sort order to search: latest, popular
 
         Raises
         ------
@@ -137,30 +96,40 @@ class Hentaifox(object):
             The list object that represents the doujin response.
         """
 
-        self.specs['query'] = query
-        self.specs['sort'] = "popular"
-        self.specs['page'] = page
+        self.specs["key"] = query
+        self.specs["sort"] = sort
+        self.specs["page"] = page
 
         query = auto_space(query)
 
-        if query == '':
-            raise ValueError('Query must be given')
-        data = requests.get(BASE_URL.hentaifox + 'args.php', params=self.specs)
+        if query == "":
+            raise ValueError("Query must be given")
+        data = requests.get(BASE_URL.hentaifox + "/search", params=self.specs)
 
-        if len(data.json()) == 0:
-            raise ValueError('No results found')
+        if len(data.json()["data"]) == 0:
+            raise ValueError("No results found")
 
         return better_object(data.json())
 
-
     async def get_random(self):
-        """Gets random doujin on hentaifox
+        """Get random doujin
+
+        Raises
+        ------
+        ValueError
+            If the doujin is not found.
 
         Returns
         -------
         dict
             The book object that represents the random doujin response.
         """
-        data = requests.get(BASE_URL.hentaifox + 'random' + '/', params=self.specs)
+
+        data = requests.get(BASE_URL.hentaifox + "/random", params=self.specs)
+
+        if data.status_code != 200:
+            raise ValueError(
+                "Request failed with status code {}".format(data.status_code)
+            )
 
         return better_object(data.json())
